#ifndef PIXELPIPELINE_H
#define PIXELPIPELINE_H

#include <pipeline.h>

class FrameBuffer;
class Texture;
class Shader;
class PixelMesh;
class MapScene;

class PixelPipeline : public Pipeline
{
private:
   FrameBuffer *m_mapFBO;
   Texture *m_mapTex;
   Shader *m_texMapShader;
   PixelMesh *m_changes;
   int m_mapWidth;
   int m_mapHeight;
   const FrameBuffer *m_targetFBO;
   Shader *m_renderShader;
   int m_width;
   int m_height;
   glm::vec3 m_camera;

   unsigned int m_vao, m_vbo;
   
public:
    PixelPipeline(MapScene *map);
    ~PixelPipeline();
    
    void pushChange(const glm::vec2 &pos, const glm::vec3 &color);
    void updateChanges();
    void setTargetFBO(FrameBuffer *fbo) {m_targetFBO = fbo;}

    virtual void renderGL(Scene *scene);
    virtual void resizeGL(int w, int h);
    
    void cameraMove(int x, int y) { m_camera.x -= x; m_camera.y += y; }
    void cameraZoom(int nbScrolls);
};

#endif // PIXELPIPELINE_H
